@@ -463,6 +463,10 @@ local $| = 1;
 
     local $\    = "\n";
 
+    # get first line of output after test header.
+
+    print '';
+
     my $argz    = &$extract_args;
     my $extract = $make_extract->( $argz );
 
