@@ -37,15 +37,14 @@ my $nil         = sub{};
 # now is ignoring the issue, letting the path do its work, and
 # leaving 'git' without an absolute path.
 
-my @checkout    = qw( git checkout  --force --overwrite-ignore  );
-my @clone       = qw( git clone     --no-checkout               );
-my @restore     = qw( git checkout  --theirs                    );
+my @checkout    = qw( git checkout  -f          );
+my @clone       = qw( git clone     -n          );
+my @restore     = qw( git checkout  --theirs    );
 
 ########################################################################
 # utility subs
 ########################################################################
 
-
 my @handlerz = 
 (
     # simplest case first, to more complicated.
